==> dodata-0.2.7.tar.gz: dodata-0.2.7/src/doplaydo/dodata/api/analysis_functions.py <==
"""Common API calls to analysis_functions."""
from __future__ import annotations


import json
import requests
from .common import url as base_url, post


def validate(
    function_name: str,
    function_path: str,
    test_model_id: int,
    target_model_name: str = "device_data",
    parameters: dict | None = None,
) -> requests.Response:
    """Validates an analysis function.

    Args:
        function_name: Name of the function to trigger.
        function_path: Path to the file to be uploaded.
        test_model_id: ID of the target model to upload to.
        target_model_name: 'device', 'die' or 'wafer'.
        parameters: for triggering analysis.
    """
    url = f"{base_url}/analysis_functions/validate_function"
    params = {
        "name": function_name,
        "test_model_id": test_model_id,
        "target_model_name": target_model_name,
    }
    data = {
        "test_kwargs": json.dumps(parameters) if parameters else "{}",
    }

    function_path = str(function_path)
    with open(function_path, "rb") as f:
        files = {"script": (function_path, f)}
        response = post(url, params=params, files=files, data=data, timeout=150)

    if response.status_code != 200:
        print(response.text)

    else:
        print(response.headers)

    return response


def _upload(
    function_name: str,
    function_path: str,
    test_model_id: int,
    target_model_name: str = "device_data",
) -> requests.Response:
    """Uploads an analysis function.

    Args:
        function_name: Name of the function to trigger.
        function_path: Path to the file to be uploaded.
        test_model_id: ID of the target model to upload to.
        target_model_name: 'device', 'die' or 'wafer'.
    """
    url = f"{base_url}/analysis_functions"
    params = {
        "name": function_name,
        "test_model_id": test_model_id,
        "target_model_name": target_model_name,
    }

    function_path = str(function_path)

    try:
        with open(function_path, "rb") as f:
            files = {"script": (function_path, f, "multipart/form-data")}
            response = post(url, params=params, files=files)
            response.raise_for_status()  # Will raise an HTTPError if the HTTP request returned an unsuccessful status code
    except requests.HTTPError as http_err:
        print(f"HTTP error occurred: {http_err}")
    except Exception as err:
        print(f"Error occurred: {err}")

    return response


def validate_and_upload(
    function_name: str,
    function_path: str,
    test_model_id: int,
    target_model_name: str = "device_data",
    parameters: dict | None = None,
) -> requests.Response:
    """Validates and uploads an analysis function.

    Args:
        function_name: Name of the function to trigger.
        function_path: Path to the file to be uploaded.
        test_model_id: ID of the target model to upload to.
        target_model_name: 'device', 'die' or 'wafer'.
        parameters: for triggering analysis.
    """
    response_validate = validate(
        function_name, function_path, test_model_id, target_model_name, parameters
    )
    if response_validate.status_code == 200:
        _upload(function_name, function_path, test_model_id, target_model_name)

    return response_validate

==> dodata-0.3.0.tar.gz: dodata-0.3.0/src/doplaydo/dodata/api/analysis_functions.py <==
"""Common API calls to analysis_functions."""
from __future__ import annotations


import json
import requests
from .common import url as base_url, post


def validate(
    function_name: str,
    function_path: str,
    test_model_id: int,
    target_model_name: str = "device_data",
    parameters: dict | None = None,
) -> requests.Response:
    """Validates an analysis function.

    Args:
        function_name: Name of the function to trigger.
        function_path: Path to the file to be uploaded.
        test_model_id: ID of the target model to upload to.
        target_model_name: 'device', 'die' or 'wafer'.
        parameters: for triggering analysis.
    """
    url = f"{base_url}/analysis_functions/validate_function"
    params = {
        "name": function_name,
        "test_model_id": test_model_id,
        "target_model_name": target_model_name,
    }
    data = {
        "test_kwargs": json.dumps(parameters) if parameters else "{}",
    }

    function_path = str(function_path)
    with open(function_path, "rb") as f:
        files = {"script": (function_path, f.read())}
        response = post(url, params=params, files=files, data=data)

    if response.status_code != 200:
        print(response.text)

    else:
        print(response.headers)

    return response


def _upload(
    function_name: str,
    function_path: str,
    test_model_id: int,
    target_model_name: str = "device_data",
) -> requests.Response:
    """Uploads an analysis function.

    Args:
        function_name: Name of the function to trigger.
        function_path: Path to the file to be uploaded.
        test_model_id: ID of the target model to upload to.
        target_model_name: 'device', 'die' or 'wafer'.
    """
    url = f"{base_url}/analysis_functions"
    params = {
        "name": function_name,
        "test_model_id": test_model_id,
        "target_model_name": target_model_name,
    }

    function_path = str(function_path)
    with open(function_path, "rb") as f:
        files = {"script": (function_path, f)}
        response = post(url, params=params, files=files)

    return response


def validate_and_upload(
    function_name: str,
    function_path: str,
    test_model_id: int,
    target_model_name: str = "device_data",
    parameters: dict | None = None,
) -> requests.Response:
    """Validates and uploads an analysis function.

    Args:
        function_name: Name of the function to trigger.
        function_path: Path to the file to be uploaded.
        test_model_id: ID of the target model to upload to.
        target_model_name: 'device', 'die' or 'wafer'.
        parameters: for triggering analysis.
    """
    response_validate = validate(
        function_name, function_path, test_model_id, target_model_name, parameters
    )
    if response_validate.status_code == 200:
        _upload(function_name, function_path, test_model_id, target_model_name)

    return response_validate
